## Version in meson.build
%global git_date  20250313
%global git_hash  a79fd6a7
%global git_ver  1.20.2
%global rel  1
%global src_name  %{name}-%{git_date}-%{git_hash}.tar.xz

Name:           foot
Version:	%{git_ver}^%{git_date}g%{git_hash}
Release:	%{rel}%{?dist}
Summary:        Fast, lightweight and minimalistic Wayland terminal emulator

License:        MIT
URL:            https://codeberg.org/dnkl/%{name}
Source0:	%{url}/%{src_name}
##
BuildRequires:  gcc
BuildRequires:  meson >= 0.58.0
BuildRequires:  desktop-file-utils
BuildRequires:  libappstream-glib
BuildRequires:  python3
BuildRequires:  systemd-rpm-macros

BuildRequires:  libutempter
BuildRequires:  pkgconfig(fcft) >= 3.0.1
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(libutf8proc)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(scdoc)
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(tllist) >= 1.0.4
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(xkbcommon)
# require *-static for header-only library
BuildRequires:  tllist-static

Recommends:     %{name}-terminfo
Requires:       (%{name}-terminfo = %{version}-%{release} if %{name}-terminfo)
# Optional dependency for bell = notify option
Recommends:     /usr/bin/notify-send
# Optional dependency for opening URLs
Recommends:     /usr/bin/xdg-open
Requires:       hicolor-icon-theme
##


%description
Fast, lightweight and minimalistic Wayland terminal emulator.
Features:
 * Fast
 * Lightweight, in dependencies, on-disk and in-memory
 * Wayland native
 * DE agnostic
 * Server/daemon mode
 * User configurable font fallback
 * On-the-fly font resize
 * On-the-fly DPI font size adjustment
 * Scrollback search
 * Keyboard driven URL detection
 * Color emoji support
 * IME (via text-input-v3)
 * Multi-seat
 * Synchronized Updates support
 * Sixel image support

%package        terminfo
Summary:        Terminfo files for %{name} terminal
BuildRequires:  /usr/bin/tic
Requires:       ncurses-base

%description    terminfo
%{summary}.


%prep
%autosetup -n %{name}


%build
%meson
%meson_build


%install
%meson_install
install -D -pv -m0644 -t %{buildroot}%{_metainfodir} \
    org.codeberg.dnkl.foot.metainfo.xml
# Will be installed to correct location with rpm macros
rm %{buildroot}%{_docdir}/%{name}/LICENSE


%check
%meson_test
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/*.metainfo.xml
desktop-file-validate \
    %{buildroot}/%{_datadir}/applications/%{name}*.desktop


%post
%systemd_user_post %{name}-server@.{service,socket}

%preun
%systemd_user_preun %{name}-server@.{service,socket}


##
%files
%license LICENSE
%config(noreplace) %{_sysconfdir}/xdg/%{name}/%{name}.ini
%{_bindir}/%{name}
%{_bindir}/%{name}client
%{_datadir}/%{name}/
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_metainfodir}/org.codeberg.dnkl.foot.metainfo.xml
%{bash_completions_dir}/foot*
%{fish_completions_dir}/foot*
%{zsh_completions_dir}/_foot*
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/CHANGELOG.md
%doc %{_docdir}/%{name}/README.md
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/%{name}client.1*
%{_mandir}/man5/%{name}.ini.5*
%{_mandir}/man7/%{name}-ctlseqs.7*
%{_userunitdir}/%{name}-server.service
%{_userunitdir}/%{name}-server.socket

%files terminfo
%license LICENSE
%dir %{_datadir}/terminfo/f
%{_datadir}/terminfo/f/%{name}
%{_datadir}/terminfo/f/%{name}-direct
##


%changelog
%autochangelog
